@@ -132,17 +132,24 @@ around run => sub ( $orig, $self, $req ) {
     my $ext_app = $Pcore::Ext::CFG->{app}->{ $self->{ext_app} };
 
     my $api_map = {
-        id        => undef,
-        namespace => 'API.' . ref( $self->{app} ) =~ s[::][]smgr,
-        timeout   => undef,
-        url       => $self->{app}->{router}->get_host_api_path( $req->{host} ),
-        type      => 'remoting',
-        version   => undef,
-        actions   => $ext_app->{api},
+
+        # type            => 'remoting',
+        type         => 'websocket',
+        id           => 'api',
+        url          => $self->{app}->{router}->get_host_api_path( $req->{host} ),
+        namespace    => 'API.' . ref( $self->{app} ) =~ s[::][]smgr,
+        actions      => $ext_app->{api},
+        timeout      => undef,
+        version      => undef,
+        maxRetries   => 0,                                                           # number of times to re-attempt delivery on failure of a call
+        headers      => undef,
+        enableBuffer => \0,                                                          # true or false to enable or disable combining of method calls. If a number is specified this is the amount of time in milliseconds to wait before sending a batched request
+
+        # enableUrlEncode => 'data',
     };
 
     my $data = {
-        INDEX => {    #
+        INDEX => {                                                                   #
             title => $self->ext_app_title
         },
         resources => $resources,
